@@ -6,9 +6,9 @@ Type annotations for dlm service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_dlm.type_defs import ActionTypeDef
+    from mypy_boto3_dlm.type_defs import ResponseMetadataTypeDef
 
-    data: ActionTypeDef = {...}
+    data: ResponseMetadataTypeDef = {...}
     ```
 """
 import sys
@@ -36,78 +36,48 @@ else:
 
 
 __all__ = (
-    "ActionTypeDef",
-    "CreateLifecyclePolicyRequestRequestTypeDef",
-    "CreateLifecyclePolicyResponseTypeDef",
+    "ResponseMetadataTypeDef",
     "CreateRuleTypeDef",
-    "CrossRegionCopyActionTypeDef",
-    "CrossRegionCopyDeprecateRuleTypeDef",
     "CrossRegionCopyRetainRuleTypeDef",
-    "CrossRegionCopyRuleTypeDef",
+    "EncryptionConfigurationTypeDef",
+    "CrossRegionCopyDeprecateRuleTypeDef",
     "DeleteLifecyclePolicyRequestRequestTypeDef",
     "DeprecateRuleTypeDef",
-    "EncryptionConfigurationTypeDef",
     "EventParametersTypeDef",
-    "EventSourceTypeDef",
     "FastRestoreRuleTypeDef",
     "GetLifecyclePoliciesRequestRequestTypeDef",
-    "GetLifecyclePoliciesResponseTypeDef",
-    "GetLifecyclePolicyRequestRequestTypeDef",
-    "GetLifecyclePolicyResponseTypeDef",
     "LifecyclePolicySummaryTypeDef",
-    "LifecyclePolicyTypeDef",
+    "GetLifecyclePolicyRequestRequestTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
-    "ListTagsForResourceResponseTypeDef",
     "ParametersTypeDef",
-    "PolicyDetailsTypeDef",
-    "ResponseMetadataTypeDef",
+    "TagTypeDef",
     "RetainRuleTypeDef",
-    "ScheduleTypeDef",
     "ShareRuleTypeDef",
     "TagResourceRequestRequestTypeDef",
-    "TagTypeDef",
     "UntagResourceRequestRequestTypeDef",
-    "UpdateLifecyclePolicyRequestRequestTypeDef",
-)
-
-ActionTypeDef = TypedDict(
-    "ActionTypeDef",
-    {
-        "Name": str,
-        "CrossRegionCopy": Sequence["CrossRegionCopyActionTypeDef"],
-    },
-)
-
-_RequiredCreateLifecyclePolicyRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateLifecyclePolicyRequestRequestTypeDef",
-    {
-        "ExecutionRoleArn": str,
-        "Description": str,
-        "State": SettablePolicyStateValuesType,
-        "PolicyDetails": "PolicyDetailsTypeDef",
-    },
-)
-_OptionalCreateLifecyclePolicyRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateLifecyclePolicyRequestRequestTypeDef",
-    {
-        "Tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateLifecyclePolicyRequestRequestTypeDef(
-    _RequiredCreateLifecyclePolicyRequestRequestTypeDef,
-    _OptionalCreateLifecyclePolicyRequestRequestTypeDef,
-):
-    pass
-
-
-CreateLifecyclePolicyResponseTypeDef = TypedDict(
     "CreateLifecyclePolicyResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "CrossRegionCopyActionTypeDef",
+    "CrossRegionCopyRuleTypeDef",
+    "EventSourceTypeDef",
+    "GetLifecyclePoliciesResponseTypeDef",
+    "ActionTypeDef",
+    "ScheduleTypeDef",
+    "PolicyDetailsTypeDef",
+    "CreateLifecyclePolicyRequestRequestTypeDef",
+    "LifecyclePolicyTypeDef",
+    "UpdateLifecyclePolicyRequestRequestTypeDef",
+    "GetLifecyclePolicyResponseTypeDef",
+)
+
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "PolicyId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -123,37 +93,6 @@ CreateRuleTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredCrossRegionCopyActionTypeDef = TypedDict(
-    "_RequiredCrossRegionCopyActionTypeDef",
-    {
-        "Target": str,
-        "EncryptionConfiguration": "EncryptionConfigurationTypeDef",
-    },
-)
-_OptionalCrossRegionCopyActionTypeDef = TypedDict(
-    "_OptionalCrossRegionCopyActionTypeDef",
-    {
-        "RetainRule": "CrossRegionCopyRetainRuleTypeDef",
-    },
-    total=False,
-)
-
-
-class CrossRegionCopyActionTypeDef(
-    _RequiredCrossRegionCopyActionTypeDef, _OptionalCrossRegionCopyActionTypeDef
-):
-    pass
-
-
-CrossRegionCopyDeprecateRuleTypeDef = TypedDict(
-    "CrossRegionCopyDeprecateRuleTypeDef",
-    {
-        "Interval": int,
-        "IntervalUnit": RetentionIntervalUnitValuesType,
-    },
-    total=False,
-)
-
 CrossRegionCopyRetainRuleTypeDef = TypedDict(
     "CrossRegionCopyRetainRuleTypeDef",
     {
@@ -163,49 +102,6 @@ CrossRegionCopyRetainRuleTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredCrossRegionCopyRuleTypeDef = TypedDict(
-    "_RequiredCrossRegionCopyRuleTypeDef",
-    {
-        "Encrypted": bool,
-    },
-)
-_OptionalCrossRegionCopyRuleTypeDef = TypedDict(
-    "_OptionalCrossRegionCopyRuleTypeDef",
-    {
-        "TargetRegion": str,
-        "Target": str,
-        "CmkArn": str,
-        "CopyTags": bool,
-        "RetainRule": "CrossRegionCopyRetainRuleTypeDef",
-        "DeprecateRule": "CrossRegionCopyDeprecateRuleTypeDef",
-    },
-    total=False,
-)
-
-
-class CrossRegionCopyRuleTypeDef(
-    _RequiredCrossRegionCopyRuleTypeDef, _OptionalCrossRegionCopyRuleTypeDef
-):
-    pass
-
-
-DeleteLifecyclePolicyRequestRequestTypeDef = TypedDict(
-    "DeleteLifecyclePolicyRequestRequestTypeDef",
-    {
-        "PolicyId": str,
-    },
-)
-
-DeprecateRuleTypeDef = TypedDict(
-    "DeprecateRuleTypeDef",
-    {
-        "Count": int,
-        "Interval": int,
-        "IntervalUnit": RetentionIntervalUnitValuesType,
-    },
-    total=False,
-)
-
 _RequiredEncryptionConfigurationTypeDef = TypedDict(
     "_RequiredEncryptionConfigurationTypeDef",
     {
@@ -227,6 +123,32 @@ class EncryptionConfigurationTypeDef(
     pass
 
 
+CrossRegionCopyDeprecateRuleTypeDef = TypedDict(
+    "CrossRegionCopyDeprecateRuleTypeDef",
+    {
+        "Interval": int,
+        "IntervalUnit": RetentionIntervalUnitValuesType,
+    },
+    total=False,
+)
+
+DeleteLifecyclePolicyRequestRequestTypeDef = TypedDict(
+    "DeleteLifecyclePolicyRequestRequestTypeDef",
+    {
+        "PolicyId": str,
+    },
+)
+
+DeprecateRuleTypeDef = TypedDict(
+    "DeprecateRuleTypeDef",
+    {
+        "Count": int,
+        "Interval": int,
+        "IntervalUnit": RetentionIntervalUnitValuesType,
+    },
+    total=False,
+)
+
 EventParametersTypeDef = TypedDict(
     "EventParametersTypeDef",
     {
@@ -236,25 +158,6 @@ EventParametersTypeDef = TypedDict(
     },
 )
 
-_RequiredEventSourceTypeDef = TypedDict(
-    "_RequiredEventSourceTypeDef",
-    {
-        "Type": Literal["MANAGED_CWE"],
-    },
-)
-_OptionalEventSourceTypeDef = TypedDict(
-    "_OptionalEventSourceTypeDef",
-    {
-        "Parameters": "EventParametersTypeDef",
-    },
-    total=False,
-)
-
-
-class EventSourceTypeDef(_RequiredEventSourceTypeDef, _OptionalEventSourceTypeDef):
-    pass
-
-
 _RequiredFastRestoreRuleTypeDef = TypedDict(
     "_RequiredFastRestoreRuleTypeDef",
     {
@@ -288,29 +191,6 @@ GetLifecyclePoliciesRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-GetLifecyclePoliciesResponseTypeDef = TypedDict(
-    "GetLifecyclePoliciesResponseTypeDef",
-    {
-        "Policies": List["LifecyclePolicySummaryTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-GetLifecyclePolicyRequestRequestTypeDef = TypedDict(
-    "GetLifecyclePolicyRequestRequestTypeDef",
-    {
-        "PolicyId": str,
-    },
-)
-
-GetLifecyclePolicyResponseTypeDef = TypedDict(
-    "GetLifecyclePolicyResponseTypeDef",
-    {
-        "Policy": "LifecyclePolicyTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 LifecyclePolicySummaryTypeDef = TypedDict(
     "LifecyclePolicySummaryTypeDef",
     {
@@ -323,21 +203,11 @@ LifecyclePolicySummaryTypeDef = TypedDict(
     total=False,
 )
 
-LifecyclePolicyTypeDef = TypedDict(
-    "LifecyclePolicyTypeDef",
+GetLifecyclePolicyRequestRequestTypeDef = TypedDict(
+    "GetLifecyclePolicyRequestRequestTypeDef",
     {
         "PolicyId": str,
-        "Description": str,
-        "State": GettablePolicyStateValuesType,
-        "StatusMessage": str,
-        "ExecutionRoleArn": str,
-        "DateCreated": datetime,
-        "DateModified": datetime,
-        "PolicyDetails": "PolicyDetailsTypeDef",
-        "Tags": Dict[str, str],
-        "PolicyArn": str,
     },
-    total=False,
 )
 
 ListTagsForResourceRequestRequestTypeDef = TypedDict(
@@ -347,14 +217,6 @@ ListTagsForResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "Tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ParametersTypeDef = TypedDict(
     "ParametersTypeDef",
     {
@@ -364,29 +226,11 @@ ParametersTypeDef = TypedDict(
     total=False,
 )
 
-PolicyDetailsTypeDef = TypedDict(
-    "PolicyDetailsTypeDef",
+TagTypeDef = TypedDict(
+    "TagTypeDef",
     {
-        "PolicyType": PolicyTypeValuesType,
-        "ResourceTypes": Sequence[ResourceTypeValuesType],
-        "ResourceLocations": Sequence[ResourceLocationValuesType],
-        "TargetTags": Sequence["TagTypeDef"],
-        "Schedules": Sequence["ScheduleTypeDef"],
-        "Parameters": "ParametersTypeDef",
-        "EventSource": "EventSourceTypeDef",
-        "Actions": Sequence["ActionTypeDef"],
-    },
-    total=False,
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
+        "Key": str,
+        "Value": str,
     },
 )
 
@@ -400,23 +244,6 @@ RetainRuleTypeDef = TypedDict(
     total=False,
 )
 
-ScheduleTypeDef = TypedDict(
-    "ScheduleTypeDef",
-    {
-        "Name": str,
-        "CopyTags": bool,
-        "TagsToAdd": Sequence["TagTypeDef"],
-        "VariableTags": Sequence["TagTypeDef"],
-        "CreateRule": "CreateRuleTypeDef",
-        "RetainRule": "RetainRuleTypeDef",
-        "FastRestoreRule": "FastRestoreRuleTypeDef",
-        "CrossRegionCopyRules": Sequence["CrossRegionCopyRuleTypeDef"],
-        "ShareRules": Sequence["ShareRuleTypeDef"],
-        "DeprecateRule": "DeprecateRuleTypeDef",
-    },
-    total=False,
-)
-
 _RequiredShareRuleTypeDef = TypedDict(
     "_RequiredShareRuleTypeDef",
     {
@@ -445,14 +272,6 @@ TagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-TagTypeDef = TypedDict(
-    "TagTypeDef",
-    {
-        "Key": str,
-        "Value": str,
-    },
-)
-
 UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
@@ -461,6 +280,179 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+CreateLifecyclePolicyResponseTypeDef = TypedDict(
+    "CreateLifecyclePolicyResponseTypeDef",
+    {
+        "PolicyId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredCrossRegionCopyActionTypeDef = TypedDict(
+    "_RequiredCrossRegionCopyActionTypeDef",
+    {
+        "Target": str,
+        "EncryptionConfiguration": EncryptionConfigurationTypeDef,
+    },
+)
+_OptionalCrossRegionCopyActionTypeDef = TypedDict(
+    "_OptionalCrossRegionCopyActionTypeDef",
+    {
+        "RetainRule": CrossRegionCopyRetainRuleTypeDef,
+    },
+    total=False,
+)
+
+
+class CrossRegionCopyActionTypeDef(
+    _RequiredCrossRegionCopyActionTypeDef, _OptionalCrossRegionCopyActionTypeDef
+):
+    pass
+
+
+_RequiredCrossRegionCopyRuleTypeDef = TypedDict(
+    "_RequiredCrossRegionCopyRuleTypeDef",
+    {
+        "Encrypted": bool,
+    },
+)
+_OptionalCrossRegionCopyRuleTypeDef = TypedDict(
+    "_OptionalCrossRegionCopyRuleTypeDef",
+    {
+        "TargetRegion": str,
+        "Target": str,
+        "CmkArn": str,
+        "CopyTags": bool,
+        "RetainRule": CrossRegionCopyRetainRuleTypeDef,
+        "DeprecateRule": CrossRegionCopyDeprecateRuleTypeDef,
+    },
+    total=False,
+)
+
+
+class CrossRegionCopyRuleTypeDef(
+    _RequiredCrossRegionCopyRuleTypeDef, _OptionalCrossRegionCopyRuleTypeDef
+):
+    pass
+
+
+_RequiredEventSourceTypeDef = TypedDict(
+    "_RequiredEventSourceTypeDef",
+    {
+        "Type": Literal["MANAGED_CWE"],
+    },
+)
+_OptionalEventSourceTypeDef = TypedDict(
+    "_OptionalEventSourceTypeDef",
+    {
+        "Parameters": EventParametersTypeDef,
+    },
+    total=False,
+)
+
+
+class EventSourceTypeDef(_RequiredEventSourceTypeDef, _OptionalEventSourceTypeDef):
+    pass
+
+
+GetLifecyclePoliciesResponseTypeDef = TypedDict(
+    "GetLifecyclePoliciesResponseTypeDef",
+    {
+        "Policies": List[LifecyclePolicySummaryTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ActionTypeDef = TypedDict(
+    "ActionTypeDef",
+    {
+        "Name": str,
+        "CrossRegionCopy": Sequence[CrossRegionCopyActionTypeDef],
+    },
+)
+
+ScheduleTypeDef = TypedDict(
+    "ScheduleTypeDef",
+    {
+        "Name": str,
+        "CopyTags": bool,
+        "TagsToAdd": Sequence[TagTypeDef],
+        "VariableTags": Sequence[TagTypeDef],
+        "CreateRule": CreateRuleTypeDef,
+        "RetainRule": RetainRuleTypeDef,
+        "FastRestoreRule": FastRestoreRuleTypeDef,
+        "CrossRegionCopyRules": Sequence[CrossRegionCopyRuleTypeDef],
+        "ShareRules": Sequence[ShareRuleTypeDef],
+        "DeprecateRule": DeprecateRuleTypeDef,
+    },
+    total=False,
+)
+
+PolicyDetailsTypeDef = TypedDict(
+    "PolicyDetailsTypeDef",
+    {
+        "PolicyType": PolicyTypeValuesType,
+        "ResourceTypes": Sequence[ResourceTypeValuesType],
+        "ResourceLocations": Sequence[ResourceLocationValuesType],
+        "TargetTags": Sequence[TagTypeDef],
+        "Schedules": Sequence[ScheduleTypeDef],
+        "Parameters": ParametersTypeDef,
+        "EventSource": EventSourceTypeDef,
+        "Actions": Sequence[ActionTypeDef],
+    },
+    total=False,
+)
+
+_RequiredCreateLifecyclePolicyRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateLifecyclePolicyRequestRequestTypeDef",
+    {
+        "ExecutionRoleArn": str,
+        "Description": str,
+        "State": SettablePolicyStateValuesType,
+        "PolicyDetails": PolicyDetailsTypeDef,
+    },
+)
+_OptionalCreateLifecyclePolicyRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateLifecyclePolicyRequestRequestTypeDef",
+    {
+        "Tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateLifecyclePolicyRequestRequestTypeDef(
+    _RequiredCreateLifecyclePolicyRequestRequestTypeDef,
+    _OptionalCreateLifecyclePolicyRequestRequestTypeDef,
+):
+    pass
+
+
+LifecyclePolicyTypeDef = TypedDict(
+    "LifecyclePolicyTypeDef",
+    {
+        "PolicyId": str,
+        "Description": str,
+        "State": GettablePolicyStateValuesType,
+        "StatusMessage": str,
+        "ExecutionRoleArn": str,
+        "DateCreated": datetime,
+        "DateModified": datetime,
+        "PolicyDetails": PolicyDetailsTypeDef,
+        "Tags": Dict[str, str],
+        "PolicyArn": str,
+    },
+    total=False,
+)
+
 _RequiredUpdateLifecyclePolicyRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateLifecyclePolicyRequestRequestTypeDef",
     {
@@ -473,7 +465,7 @@ _OptionalUpdateLifecyclePolicyRequestRequestTypeDef = TypedDict(
         "ExecutionRoleArn": str,
         "State": SettablePolicyStateValuesType,
         "Description": str,
-        "PolicyDetails": "PolicyDetailsTypeDef",
+        "PolicyDetails": PolicyDetailsTypeDef,
     },
     total=False,
 )
@@ -484,3 +476,12 @@ class UpdateLifecyclePolicyRequestRequestTypeDef(
     _OptionalUpdateLifecyclePolicyRequestRequestTypeDef,
 ):
     pass
+
+
+GetLifecyclePolicyResponseTypeDef = TypedDict(
+    "GetLifecyclePolicyResponseTypeDef",
+    {
+        "Policy": LifecyclePolicyTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
